@@ -25,10 +25,13 @@
 
 #include <sigc++/trackable.h>
 
+#include "sharp/modulefactory.hpp"
+
 namespace gnote {
 
 class AbstractAddin
-  : public sigc::trackable
+  : public sharp::IInterface
+  , public sigc::trackable
 {
 public:
   AbstractAddin();
